@@ -22,3 +22,10 @@ def goodbye_prefect_collection() -> str:
     """
     return "Goodbye, prefect-collection!"
 
+
+@task
+def really_swell_task() -> str:
+    """
+    A really swell task
+    """
+    return "This is a really swell task!"
